# Source: https://www.nbb.be/fr/paiements-et-titres/standards-de-paiements/codes-didentification-des-banques
# File = https://www.nbb.be/doc/be/be/protocol/r_fulllist_of_codes_current.xlsx

BE_BIC_BY_ACCOUNT_NUMBER = {
        "000": "BPOTBEB1",
        "001": "GEBABEBB",
        "002": "GEBABEBB",
        "003": "GEBABEBB",
        "004": "GEBABEBB",
        "005": "GEBABEBB",
        "006": "GEBABEBB",
        "007": "GEBABEBB",
        "008": "GEBABEBB",
        "009": "GEBABEBB",
        "010": "GEBABEBB",
        "011": "GEBABEBB",
        "012": "GEBABEBB",
        "013": "GEBABEBB",
        "014": "GEBABEBB",
        "015": "GEBABEBB",
        "016": "GEBABEBB",
        "017": "GEBABEBB",
        "018": "GEBABEBB",
        "019": "GEBABEBB",
        "020": "GEBABEBB",
        "021": "GEBABEBB",
        "022": "GEBABEBB",
        "023": "GEBABEBB",
        "024": "GEBABEBB",
        "025": "GEBABEBB",
        "026": "GEBABEBB",
        "027": "GEBABEBB",
        "028": "GEBABEBB",
        "029": "GEBABEBB",
        "030": "GEBABEBB",
        "031": "GEBABEBB",
        "032": "GEBABEBB",
        "033": "GEBABEBB",
        "034": "GEBABEBB",
        "035": "GEBABEBB",
        "036": "GEBABEBB",
        "037": "GEBABEBB",
        "038": "GEBABEBB",
        "039": "GEBABEBB",
        "040": "GEBABEBB",
        "041": "GEBABEBB",
        "042": "GEBABEBB",
        "043": "GEBABEBB",
        "044": "GEBABEBB",
        "045": "GEBABEBB",
        "046": "GEBABEBB",
        "047": "GEBABEBB",
        "048": "GEBABEBB",
        "049": "GEBABEBB",
        "050": "GKCCBEBB",
        "051": "GKCCBEBB",
        "052": "GKCCBEBB",
        "053": "GKCCBEBB",
        "054": "GKCCBEBB",
        "055": "GKCCBEBB",
        "056": "GKCCBEBB",
        "057": "GKCCBEBB",
        "058": "GKCCBEBB",
        "059": "GKCCBEBB",
        "060": "GKCCBEBB",
        "061": "GKCCBEBB",
        "062": "GKCCBEBB",
        "063": "GKCCBEBB",
        "064": "GKCCBEBB",
        "065": "GKCCBEBB",
        "066": "GKCCBEBB",
        "067": "GKCCBEBB",
        "068": "GKCCBEBB",
        "069": "GKCCBEBB",
        "070": "GKCCBEBB",
        "071": "GKCCBEBB",
        "072": "GKCCBEBB",
        "073": "GKCCBEBB",
        "074": "GKCCBEBB",
        "075": "GKCCBEBB",
        "076": "GKCCBEBB",
        "077": "GKCCBEBB",
        "078": "GKCCBEBB",
        "079": "GKCCBEBB",
        "080": "GKCCBEBB",
        "081": "GKCCBEBB",
        "082": "GKCCBEBB",
        "083": "GKCCBEBB",
        "084": "GKCCBEBB",
        "085": "GKCCBEBB",
        "086": "GKCCBEBB",
        "087": "GKCCBEBB",
        "088": "GKCCBEBB",
        "089": "GKCCBEBB",
        "090": "GKCCBEBB",
        "091": "GKCCBEBB",
        "092": "GKCCBEBB",
        "093": "GKCCBEBB",
        "094": "GKCCBEBB",
        "095": "GKCCBEBB",
        "096": "GKCCBEBB",
        "097": "GKCCBEBB",
        "098": "GKCCBEBB",
        "099": "GKCCBEBB",
        "100": "NBBEBEBB203",
        "101": "NBBEBEBB203",
        "103": "NICABEBB",
        "104": "NICABEBB",
        "105": "NICABEBB",
        "106": "NICABEBB",
        "107": "NICABEBB",
        "108": "NICABEBB",
        "109": "CTBKBEBX",
        "110": "CTBKBEBX",
        "111": "ABERBE22",
        "113": "CTBKBEBX",
        "114": "CTBKBEBX",
        "119": "CTBKBEBX",
        "120": "CTBKBEBX",
        "121": "CTBKBEBX",
        "122": "CTBKBEBX",
        "123": "CTBKBEBX",
        "124": "CTBKBEBX",
        "125": "CPHBBE75",
        "126": "CPHBBE75",
        "127": "CTBKBEBX",
        "129": "CTBKBEBX",
        "131": "CTBKBEBX",
        "132": "BNAGBEBB",
        "133": "CTBKBEBX",
        "134": "CTBKBEBX",
        "137": "GEBABEBB",
        "140": "GEBABEBB",
        "141": "GEBABEBB",
        "142": "GEBABEBB",
        "143": "GEBABEBB",
        "144": "GEBABEBB",
        "145": "GEBABEBB",
        "146": "GEBABEBB",
        "147": "GEBABEBB",
        "148": "GEBABEBB",
        "149": "GEBABEBB",
        "150": "BCMCBEBB",
        "171": "CPHBBE75",
        "172": "RABOBE23",
        "173": "RABOBE23",
        "176": "BSCHBEBBRET",
        "178": "COBABEBX",
        "179": "COBABEBX",
        "183": "BARBBEBB",
        "185": "HBKABE22",
        "189": "SMBCBEBB",
        "190": "CREGBEBB",
        "191": "CREGBEBB",
        "192": "CREGBEBB",
        "193": "CREGBEBB",
        "194": "CREGBEBB",
        "195": "CREGBEBB",
        "196": "CREGBEBB",
        "197": "CREGBEBB",
        "198": "CREGBEBB",
        "199": "CREGBEBB",
        "200": "GEBABEBB",
        "201": "GEBABEBB",
        "202": "GEBABEBB",
        "203": "GEBABEBB",
        "204": "GEBABEBB",
        "205": "GEBABEBB",
        "206": "GEBABEBB",
        "207": "GEBABEBB",
        "208": "GEBABEBB",
        "209": "GEBABEBB",
        "210": "GEBABEBB",
        "211": "GEBABEBB",
        "212": "GEBABEBB",
        "213": "GEBABEBB",
        "214": "GEBABEBB",
        "220": "GEBABEBB",
        "221": "GEBABEBB",
        "222": "GEBABEBB",
        "223": "GEBABEBB",
        "224": "GEBABEBB",
        "225": "GEBABEBB",
        "226": "GEBABEBB",
        "227": "GEBABEBB",
        "228": "GEBABEBB",
        "229": "GEBABEBB",
        "230": "GEBABEBB",
        "231": "GEBABEBB",
        "232": "GEBABEBB",
        "233": "GEBABEBB",
        "234": "GEBABEBB",
        "235": "GEBABEBB",
        "236": "GEBABEBB",
        "237": "GEBABEBB",
        "238": "GEBABEBB",
        "239": "GEBABEBB",
        "240": "GEBABEBB",
        "241": "GEBABEBB",
        "242": "GEBABEBB",
        "243": "GEBABEBB",
        "244": "GEBABEBB",
        "245": "GEBABEBB",
        "246": "GEBABEBB",
        "247": "GEBABEBB",
        "248": "GEBABEBB",
        "249": "GEBABEBB",
        "250": "GEBABEBB",
        "251": "GEBABEBB",
        "252": "GEBABEBB",
        "253": "GEBABEBB",
        "254": "GEBABEBB",
        "255": "GEBABEBB",
        "256": "GEBABEBB",
        "257": "GEBABEBB",
        "258": "GEBABEBB",
        "259": "GEBABEBB",
        "260": "GEBABEBB",
        "261": "GEBABEBB",
        "262": "GEBABEBB",
        "263": "GEBABEBB",
        "264": "GEBABEBB",
        "265": "GEBABEBB",
        "266": "GEBABEBB",
        "267": "GEBABEBB",
        "268": "GEBABEBB",
        "269": "GEBABEBB",
        "270": "GEBABEBB",
        "271": "GEBABEBB",
        "272": "GEBABEBB",
        "273": "GEBABEBB",
        "274": "GEBABEBB",
        "275": "GEBABEBB",
        "276": "GEBABEBB",
        "277": "GEBABEBB",
        "278": "GEBABEBB",
        "279": "GEBABEBB",
        "280": "GEBABEBB",
        "281": "GEBABEBB",
        "282": "GEBABEBB",
        "283": "GEBABEBB",
        "284": "GEBABEBB",
        "285": "GEBABEBB",
        "286": "GEBABEBB",
        "287": "GEBABEBB",
        "288": "GEBABEBB",
        "289": "GEBABEBB",
        "290": "GEBABEBB",
        "291": "GEBABEBB",
        "292": "GEBABEBB",
        "293": "GEBABEBB",
        "294": "GEBABEBB",
        "295": "GEBABEBB",
        "296": "GEBABEBB",
        "297": "GEBABEBB",
        "298": "GEBABEBB",
        "299": "BPOTBEB1",
        "300": "BBRUBEBB",
        "301": "BBRUBEBB",
        "302": "BBRUBEBB",
        "303": "BBRUBEBB",
        "304": "BBRUBEBB",
        "305": "BBRUBEBB",
        "306": "BBRUBEBB",
        "307": "BBRUBEBB",
        "308": "BBRUBEBB",
        "309": "BBRUBEBB",
        "310": "BBRUBEBB",
        "311": "BBRUBEBB",
        "312": "BBRUBEBB",
        "313": "BBRUBEBB",
        "314": "BBRUBEBB",
        "315": "BBRUBEBB",
        "316": "BBRUBEBB",
        "317": "BBRUBEBB",
        "318": "BBRUBEBB",
        "319": "BBRUBEBB",
        "320": "BBRUBEBB",
        "321": "BBRUBEBB",
        "322": "BBRUBEBB",
        "323": "BBRUBEBB",
        "324": "BBRUBEBB",
        "325": "BBRUBEBB",
        "326": "BBRUBEBB",
        "327": "BBRUBEBB",
        "328": "BBRUBEBB",
        "329": "BBRUBEBB",
        "330": "BBRUBEBB",
        "331": "BBRUBEBB",
        "332": "BBRUBEBB",
        "333": "BBRUBEBB",
        "334": "BBRUBEBB",
        "335": "BBRUBEBB",
        "336": "BBRUBEBB",
        "337": "BBRUBEBB",
        "338": "BBRUBEBB",
        "339": "BBRUBEBB",
        "340": "BBRUBEBB",
        "341": "BBRUBEBB",
        "342": "BBRUBEBB",
        "343": "BBRUBEBB",
        "344": "BBRUBEBB",
        "345": "BBRUBEBB",
        "346": "BBRUBEBB",
        "347": "BBRUBEBB",
        "348": "BBRUBEBB",
        "349": "BBRUBEBB",
        "350": "BBRUBEBB",
        "351": "BBRUBEBB",
        "352": "BBRUBEBB",
        "353": "BBRUBEBB",
        "354": "BBRUBEBB",
        "355": "BBRUBEBB",
        "356": "BBRUBEBB",
        "357": "BBRUBEBB",
        "358": "BBRUBEBB",
        "359": "BBRUBEBB",
        "360": "BBRUBEBB",
        "361": "BBRUBEBB",
        "362": "BBRUBEBB",
        "363": "BBRUBEBB",
        "364": "BBRUBEBB",
        "365": "BBRUBEBB",
        "366": "BBRUBEBB",
        "367": "BBRUBEBB",
        "368": "BBRUBEBB",
        "369": "BBRUBEBB",
        "370": "BBRUBEBB",
        "371": "BBRUBEBB",
        "372": "BBRUBEBB",
        "373": "BBRUBEBB",
        "374": "BBRUBEBB",
        "375": "BBRUBEBB",
        "376": "BBRUBEBB",
        "377": "BBRUBEBB",
        "378": "BBRUBEBB",
        "379": "BBRUBEBB",
        "380": "BBRUBEBB",
        "381": "BBRUBEBB",
        "382": "BBRUBEBB",
        "383": "BBRUBEBB",
        "384": "BBRUBEBB",
        "385": "BBRUBEBB",
        "386": "BBRUBEBB",
        "387": "BBRUBEBB",
        "388": "BBRUBEBB",
        "389": "BBRUBEBB",
        "390": "BBRUBEBB",
        "391": "BBRUBEBB",
        "392": "BBRUBEBB",
        "393": "BBRUBEBB",
        "394": "BBRUBEBB",
        "395": "BBRUBEBB",
        "396": "BBRUBEBB",
        "397": "BBRUBEBB",
        "398": "BBRUBEBB",
        "399": "BBRUBEBB",
        "400": "KREDBEBB",
        "401": "KREDBEBB",
        "402": "KREDBEBB",
        "403": "KREDBEBB",
        "404": "KREDBEBB",
        "405": "KREDBEBB",
        "406": "KREDBEBB",
        "407": "KREDBEBB",
        "408": "KREDBEBB",
        "409": "KREDBEBB",
        "410": "KREDBEBB",
        "411": "KREDBEBB",
        "412": "KREDBEBB",
        "413": "KREDBEBB",
        "414": "KREDBEBB",
        "415": "KREDBEBB",
        "416": "KREDBEBB",
        "417": "KREDBEBB",
        "418": "KREDBEBB",
        "419": "KREDBEBB",
        "420": "KREDBEBB",
        "421": "KREDBEBB",
        "422": "KREDBEBB",
        "423": "KREDBEBB",
        "424": "KREDBEBB",
        "425": "KREDBEBB",
        "426": "KREDBEBB",
        "427": "KREDBEBB",
        "428": "KREDBEBB",
        "429": "KREDBEBB",
        "430": "KREDBEBB",
        "431": "KREDBEBB",
        "432": "KREDBEBB",
        "433": "KREDBEBB",
        "434": "KREDBEBB",
        "435": "KREDBEBB",
        "436": "KREDBEBB",
        "437": "KREDBEBB",
        "438": "KREDBEBB",
        "439": "KREDBEBB",
        "440": "KREDBEBB",
        "441": "KREDBEBB",
        "442": "KREDBEBB",
        "443": "KREDBEBB",
        "444": "KREDBEBB",
        "445": "KREDBEBB",
        "446": "KREDBEBB",
        "447": "KREDBEBB",
        "448": "KREDBEBB",
        "449": "KREDBEBB",
        "450": "KREDBEBB",
        "451": "KREDBEBB",
        "452": "KREDBEBB",
        "453": "KREDBEBB",
        "454": "KREDBEBB",
        "455": "KREDBEBB",
        "456": "KREDBEBB",
        "457": "KREDBEBB",
        "458": "KREDBEBB",
        "459": "KREDBEBB",
        "460": "KREDBEBB",
        "461": "KREDBEBB",
        "462": "KREDBEBB",
        "463": "KREDBEBB",
        "464": "KREDBEBB",
        "465": "KREDBEBB",
        "466": "KREDBEBB",
        "467": "KREDBEBB",
        "468": "KREDBEBB",
        "469": "KREDBEBB",
        "470": "KREDBEBB",
        "471": "KREDBEBB",
        "472": "KREDBEBB",
        "473": "KREDBEBB",
        "474": "KREDBEBB",
        "475": "KREDBEBB",
        "476": "KREDBEBB",
        "477": "KREDBEBB",
        "478": "KREDBEBB",
        "479": "KREDBEBB",
        "480": "KREDBEBB",
        "481": "KREDBEBB",
        "482": "KREDBEBB",
        "483": "KREDBEBB",
        "484": "KREDBEBB",
        "485": "KREDBEBB",
        "486": "KREDBEBB",
        "487": "KREDBEBB",
        "488": "KREDBEBB",
        "489": "KREDBEBB",
        "490": "KREDBEBB",
        "491": "KREDBEBB",
        "492": "KREDBEBB",
        "493": "KREDBEBB",
        "494": "KREDBEBB",
        "495": "KREDBEBB",
        "496": "KREDBEBB",
        "497": "KREDBEBB",
        "498": "KREDBEBB",
        "499": "KREDBEBB",
        "500": "MTPSBEBB",
        "501": "DHBNBEBB",
        "504": "PANXBEB1",
        "507": "DIERBE21",
        "508": "PARBBEBZMDC",
        "509": "ABNABE2AIPC",
        "510": "VAPEBE22",
        "512": "DNIBBE21",
        "513": "SGPBBE99",
        "514": "PUILBEBB",
        "515": "IRVTBEBB",
        "519": "BNYMBEBB",
        "521": "FVLBBE22",
        "522": "UTWBBEBB",
        "523": "TRIOBEBB",
        "524": "WAFABEBB",
        "525": "FVLBBE2E",
        "530": "SHIZBEBB",
        "535": "FBHLBE22",
        "541": "BKIDBE22",
        "546": "WAFABEBB",
        "548": "LOCYBEBB",
        "549": "CHASBEBX",
        "550": "GKCCBEBB",
        "551": "GKCCBEBB",
        "552": "GKCCBEBB",
        "553": "GKCCBEBB",
        "554": "GKCCBEBB",
        "555": "GKCCBEBB",
        "556": "GKCCBEBB",
        "557": "GKCCBEBB",
        "558": "GKCCBEBB",
        "559": "GKCCBEBB",
        "560": "GKCCBEBB",
        "562": "GKCCBEBB",
        "563": "GKCCBEBB",
        "564": "GKCCBEBB",
        "565": "GKCCBEBB",
        "566": "GKCCBEBB",
        "567": "GKCCBEBB",
        "568": "GKCCBEBB",
        "569": "GKCCBEBB",
        "570": "CITIBEBX",
        "571": "CITIBEBX",
        "572": "CITIBEBX",
        "573": "CITIBEBX",
        "574": "CITIBEBX",
        "575": "CITIBEBX",
        "576": "CITIBEBX",
        "577": "CITIBEBX",
        "578": "CITIBEBX",
        "579": "CITIBEBX",
        "581": "MHCBBEBB",
        "583": "DEGRBEBB",
        "585": "RCBPBEBB",
        "586": "CFFRBEB1",
        "587": "BIBLBE21",
        "588": "CMCIBEB1BTB",
        "590": "BSCHBEBB",
        "591": "BSCHBEBB",
        "592": "BSCHBEBB",
        "593": "BSCHBEBB",
        "594": "BSCHBEBB",
        "595": "CTBKBEBX",
        "596": "CTBKBEBX",
        "597": "CTBKBEBX",
        "598": "CTBKBEBX",
        "599": "CTBKBEBX",
        "600": "CTBKBEBX",
        "601": "CTBKBEBX",
        "605": "BKCHBEBB",
        "607": "ICBKBEBB",
        "610": "DEUTBEBE",
        "611": "DEUTBEBE",
        "612": "DEUTBEBE",
        "613": "DEUTBEBE",
        "624": "GKCCBEBB",
        "625": "GKCCBEBB",
        "630": "BBRUBEBB",
        "631": "BBRUBEBB",
        "634": "BNAGBEBB",
        "635": "BNAGBEBB",
        "636": "BNAGBEBB",
        "638": "GKCCBEBB",
        "639": "ABNABE2AMYO",
        "640": "ADIABE22",
        "642": "BBVABEBB",
        "643": "BMPBBEBB",
        "645": "JVBABE22",
        "646": "BNAGBEBB",
        "647": "BNAGBEBB",
        "651": "KEYTBEBB",
        "652": "HBKABE22",
        "657": "GKCCBEBB",
        "658": "HABBBEBB",
        "663": "BMEUBEB1",
        "664": "BCDMBEBB",
        "668": "SBINBE2X",
        "670": "NYA",
        "671": "EURBBE99",
        "672": "GKCCBEBB",
        "673": "HBKABE22",
        "674": "ABNABE2AIDJ",
        "675": "BYBBBEBB",
        "676": "DEGRBEBB",
        "677": "CBPXBE99",
        "678": "DELEBE22",
        "679": "PCHQBEBB",
        "680": "GKCCBEBB",
        "682": "GKCCBEBB",
        "683": "GKCCBEBB",
        "685": "BOFABE3X",
        "686": "BOFABE3X",
        "687": "MGTCBEBE",
        "688": "SGABBEB2",
        "693": "BOTKBEBX",
        "694": "DEUTBEBE",
        "696": "CRLYBEBB",
        "698": "NATXBEB1",
        "700": "AXABBE22",
        "701": "AXABBE22",
        "702": "AXABBE22",
        "703": "AXABBE22",
        "704": "AXABBE22",
        "705": "AXABBE22",
        "706": "AXABBE22",
        "707": "AXABBE22",
        "708": "AXABBE22",
        "709": "AXABBE22",
        "719": "ABNABE2AXXX",
        "722": "ABNABE2AIPC",
        "725": "KREDBEBB",
        "726": "KREDBEBB",
        "727": "KREDBEBB",
        "728": "CREGBEBB",
        "729": "CREGBEBB",
        "730": "KREDBEBB",
        "731": "KREDBEBB",
        "732": "CREGBEBB",
        "733": "KREDBEBB",
        "734": "KREDBEBB",
        "735": "KREDBEBB",
        "736": "KREDBEBB",
        "737": "KREDBEBB",
        "738": "KREDBEBB",
        "739": "KREDBEBB",
        "740": "KREDBEBB",
        "741": "KREDBEBB",
        "742": "CREGBEBB",
        "743": "KREDBEBB",
        "744": "KREDBEBB",
        "745": "KREDBEBB",
        "746": "KREDBEBB",
        "747": "KREDBEBB",
        "748": "KREDBEBB",
        "749": "KREDBEBB",
        "750": "AXABBE22",
        "751": "AXABBE22",
        "752": "AXABBE22",
        "753": "AXABBE22",
        "754": "AXABBE22",
        "755": "AXABBE22",
        "756": "AXABBE22",
        "757": "AXABBE22",
        "758": "AXABBE22",
        "759": "AXABBE22",
        "760": "AXABBE22",
        "761": "AXABBE22",
        "762": "AXABBE22",
        "763": "AXABBE22",
        "764": "AXABBE22",
        "765": "AXABBE22",
        "766": "AXABBE22",
        "767": "AXABBE22",
        "768": "AXABBE22",
        "769": "AXABBE22",
        "770": "AXABBE22",
        "771": "AXABBE22",
        "772": "AXABBE22",
        "773": "AXABBE22",
        "774": "AXABBE22",
        "775": "GKCCBEBB",
        "776": "GKCCBEBB",
        "777": "GKCCBEBB",
        "778": "GKCCBEBB",
        "779": "GKCCBEBB",
        "780": "GKCCBEBB",
        "781": "GKCCBEBB",
        "782": "GKCCBEBB",
        "783": "GKCCBEBB",
        "784": "GKCCBEBB",
        "785": "GKCCBEBB",
        "786": "GKCCBEBB",
        "787": "GKCCBEBB",
        "788": "GKCCBEBB",
        "789": "GKCCBEBB",
        "790": "GKCCBEBB",
        "791": "GKCCBEBB",
        "792": "GKCCBEBB",
        "793": "GKCCBEBB",
        "794": "GKCCBEBB",
        "795": "GKCCBEBB",
        "796": "GKCCBEBB",
        "797": "GKCCBEBB",
        "798": "GKCCBEBB",
        "799": "GKCCBEBB",
        "800": "AXABBE22",
        "801": "AXABBE22",
        "802": "AXABBE22",
        "803": "AXABBE22",
        "804": "AXABBE22",
        "805": "AXABBE22",
        "806": "AXABBE22",
        "807": "AXABBE22",
        "808": "AXABBE22",
        "809": "AXABBE22",
        "810": "AXABBE22",
        "811": "AXABBE22",
        "812": "AXABBE22",
        "813": "AXABBE22",
        "814": "AXABBE22",
        "815": "AXABBE22",
        "816": "AXABBE22",
        "817": "ISAEBEBB",
        "823": "BLUXBEBB",
        "825": "DEUTBEBE",
        "826": "DEUTBEBE",
        "828": "HBKABE22",
        "830": "GKCCBEBB",
        "831": "GKCCBEBB",
        "832": "GKCCBEBB",
        "833": "GKCCBEBB",
        "834": "GKCCBEBB",
        "835": "GKCCBEBB",
        "836": "GKCCBEBB",
        "837": "GKCCBEBB",
        "838": "GKCCBEBB",
        "839": "GKCCBEBB",
        "840": "PRIBBEBB",
        "844": "RABOBE22",
        "845": "DEGRBEBB",
        "850": "NICABEBB",
        "851": "NICABEBB",
        "852": "NICABEBB",
        "853": "NICABEBB",
        "859": "NICABEBB",
        "860": "NICABEBB",
        "862": "NICABEBB",
        "863": "NICABEBB",
        "865": "NICABEBB",
        "866": "NICABEBB",
        "868": "KREDBEBB",
        "871": "BNAGBEBB",
        "873": "PCHQBEBB",
        "876": "MBWMBEBB",
        "877": "BNAGBEBB",
        "878": "BNAGBEBB",
        "879": "BNAGBEBB",
        "880": "HBKABE22",
        "881": "HBKABE22",
        "882": "HBKABE22",
        "883": "HBKABE22",
        "884": "HBKABE22",
        "885": "HBKABE22",
        "886": "HBKABE22",
        "887": "HBKABE22",
        "888": "HBKABE22",
        "889": "HBKABE22",
        "890": "VDSPBE91",
        "891": "VDSPBE91",
        "892": "VDSPBE91",
        "893": "VDSPBE91",
        "894": "VDSPBE91",
        "895": "VDSPBE91",
        "896": "VDSPBE91",
        "897": "VDSPBE91",
        "898": "VDSPBE91",
        "899": "VDSPBE91",
        "906": "CEKVBE81",
        "908": "CEKVBE81",
        "910": "HBKABE22",
        "911": "TUNZBEB1",
        "913": "EPBFBEBB",
        "914": "FXBBBEBB",
        "915": "OONXBEBB",
        "916": "GOCFBEB1",
        "920": "HBKABE22",
        "921": "HBKABE22",
        "922": "HBKABE22",
        "923": "HBKABE22",
        "924": "FMMSBEB1",
        "925": "HBKABE22",
        "926": "EBPBBEB1",
        "928": "VPAYBE21",
        "929": "HBKABE22",
        "930": "HBKABE22",
        "931": "HBKABE22",
        "932": "HBKABE22",
        "933": "HBKABE22",
        "934": "HBKABE22",
        "935": "HBKABE22",
        "936": "HBKABE22",
        "937": "HBKABE22",
        "938": "HBKABE22",
        "939": "HBKABE22",
        "940": "CLIQBEB1",
        "941": "CVMCBEBB",
        "942": "PUILBEBB",
        "944": "NYA",
        "945": "JPMGBEBB",
        "948": "NYA",
        "949": "HSBCBEBB",
        "950": "CTBKBEBX",
        "951": "CTBKBEBX",
        "952": "CTBKBEBX",
        "953": "CTBKBEBX",
        "954": "CTBKBEBX",
        "955": "CTBKBEBX",
        "956": "CTBKBEBX",
        "957": "CTBKBEBX",
        "958": "CTBKBEBX",
        "959": "CTBKBEBX",
        "960": "ABNABE2AIPC",
        "961": "HBKABE22",
        "963": "AXABBE22",
        "967": "TRWIBEB1",
        "968": "ENIBBEBB",
        "969": "PUILBEBB",
        "970": "HBKABE22",
        "971": "HBKABE22",
        "973": "ARSPBE22",
        "975": "AXABBE22",
        "976": "HBKABE22",
        "978": "ARSPBE22",
        "979": "ARSPBE22",
        "980": "ARSPBE22",
        "981": "PCHQBEBB",
        "982": "PCHQBEBB",
        "983": "PCHQBEBB",
        "984": "PCHQBEBB",
        "985": "BPOTBEB1",
        "986": "BPOTBEB1",
        "987": "BPOTBEB1",
        "988": "BPOTBEB1",
}

BE_BANK_NAME_BY_BIC = {
        "ABERBE22": "Bank J. Van Breda & C°",
        "ABNABE2AIDJ": "ABN AMRO Bank N.V.",
        "ABNABE2AIPC": "ABN AMRO Bank N.V.",
        "ABNABE2AMYO": "ABN AMRO Bank N.V.",
        "ABNABE2AXXX": "ABN AMRO Bank N.V.",
        "ADIABE22": "KBC Bank N.V. Business Center Diamant",
        "ARSPBE22": "Argenta Banque d'Epargne (ASPA)",
        "AXABBE22": "AXA Bank Belgium",
        "BARBBEBB": "Bank of Baroda",
        "BBRUBEBB": "ING Belgique",
        "BBVABEBB": "Banco Bilbao Vizcaya Argentaria",
        "BCDMBEBB": "Banque Chaabi du Maroc",
        "BCMCBEBB": "Bancontact Payconiq Company",
        "BIBLBE21": "BinckBank",
        "BKCHBEBB": "Bank of China (Luxembourg) S.A., Brussels Branch",
        "BKIDBE22": "BANK OF INDIA",
        "BLUXBEBB": "Banque de Luxembourg",
        "BMEUBEB1": "BMCE Euro Services",
        "BMPBBEBB": "Banca Monte Paschi Belgio",
        "BNAGBEBB": "Banque Nagelmackers",
        "BNYMBEBB": "The Bank of New York Mellon",
        "BOFABE3X": "Bank of Amerika Merrill Lynch International DAC - Brussels Branch",
        "BOTKBEBX": "MUFG Bank (Europe)",
        "BPOTBEB1": "bpost bank",
        "BSCHBEBB": "Santander Consumer Bank",
        "BSCHBEBBRET": "Santander Consumer Bank",
        "BYBBBEBB": "Byblos Bank Europe",
        "CBPXBE99": "Compagnie de Banque Privée Quilvest",
        "CEKVBE81": "Centrale Kredietverlening (C.K.V.)",
        "CFFRBEB1": "Crédit Foncier de France",
        "CHASBEBX": "JP Morgan Chase Bank",
        "CITIBEBX": "Citibank Europe Plc - Belgium Branch",
        "CLIQBEB1": "Banque Centrale de Compensation (Clearnet)",
        "CMCIBEB1BTB": "Banque Transatlantique Belgium",
        "COBABEBX": "Commerzbank",
        "CPHBBE75": "Banque CPH",
        "CREGBEBB": "CBC Banque et Assurances",
        "CRLYBEBB": "Crédit Agricole Corporate & Investment Bank",
        "CTBKBEBX": "Beobank",
        "CVMCBEBB": "C A Indosuez Wealth (Europe)",
        "DEGRBEBB": "Banque Degroof Petercam Luxembourg",
        "DELEBE22": "Delen Private Bank",
        "DEUTBEBE": "Deutsche Bank AG",
        "DHBNBEBB": "Demir-Halk Bank (Nederland) (DHB)",
        "DIERBE21": "Dierickx, Leys & Cie Effectenbank",
        "DNIBBE21": "NIBC BANK",
        "EBPBBEB1": "Ebury Partners Belgium",
        "ENIBBEBB": "Banque Eni",
        "EPBFBEBB": "EPBF",
        "EURBBE99": "Europabank",
        "FBHLBE22": "CREDIT EUROPE BANK NV",
        "FMMSBEB1": "Fimaser",
        "FVLBBE22": "F. van Lanschot Bankiers",
        "FVLBBE2E": "F. van Lanschot Bankiers",
        "FXBBBEBB": "FX4BIZ",
        "GEBABEBB": "BNP Paribas Fortis",
        "GKCCBEBB": "BELFIUS BANQUE",
        "GOCFBEB1": "GOLD COMMODITIES FOREX (G.C.F.)",
        "HABBBEBB": "Habib Bank",
        "HBKABE22": "ING Belgique",
        "HSBCBEBB": "HSBC France Belgian Branch",
        "ICBKBEBB": "Industrial and Commercial Bank of China (Europe)",
        "IRVTBEBB": "The Bank of New York Mellon NV/SA",
        "ISAEBEBB": "CACEIS Bank Belgian Branch",
        "JPMGBEBB": "J.P. Morgan Bank Luxembourg - Brussels Branch",
        "JVBABE22": "Bank J. Van Breda & C°",
        "KEYTBEBB": "Arkéa Direct Bank (nom commercial / commerciële naam: Keytrade Bank)",
        "KREDBEBB": "KBC Bank",
        "LOCYBEBB": "Lombard Odier (Europe)",
        "MBWMBEBB": "MeDirect Bank S.A.",
        "MGTCBEBE": "Euroclear Bank",
        "MHCBBEBB": "Mizuho Bank Europe N.V. Brussels Branch",
        "MTPSBEBB": "Moneytrans Payment Services",
        "NATXBEB1": "Natixis Bank",
        "NBBEBEBB203": "Banque Nationale de Belgique",
        "NICABEBB": "Crelan",
        "NYA": "CNH Industrial Capital EUROPE",
        "OONXBEBB": "Oonex",
        "PANXBEB1": "PAY-NXT",
        "PARBBEBZMDC": "BNP Paribas Securities Services",
        "PCHQBEBB": "bpost",
        "PRIBBEBB": "Edmond de Rothschild (Europe)",
        "PUILBEBB": "Puilaetco Dewaay Private Bankers",
        "RABOBE22": "Rabobank.be",
        "RABOBE23": "Coöperatieve Rabobank U.A.",
        "RCBPBEBB": "Rothschild Belgique Succursale Rothschild Martin Maurel",
        "SBINBE2X": "State Bank of India",
        "SGABBEB2": "Société Générale (Paris)",
        "SGPBBE99": "ABN AMRO Private Banking Belgium",
        "SHIZBEBB": "Shizuoka Bank (Europe)",
        "SMBCBEBB": "Sumitomo Mitsui Banking Corporation (SMBC)",
        "TRIOBEBB": "Banque Triodos",
        "TRWIBEB1": "TransferWise",
        "TUNZBEB1": "Ingenico Financial Solutions",
        "UTWBBEBB": "United Taiwan Bank",
        "VAPEBE22": "VAN DE PUT & CO Banquiers Privés",
        "VDSPBE91": "vdk bank",
        "VPAYBE21": "VIVA Payment Services",
        "WAFABEBB": "Attijariwafa bank Europe",
}

